==> proshade-0.7.6.0.tar.gz: proshade-0.7.6.0/proshade/documentation/html/search/all_0.js <==
var searchData=
[
  ['aangle_0',['aAngle',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa75beee618649d6fd9dc850a5a66a551',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['addaxisunlesssame_1',['addAxisUnlessSame',['../namespace_pro_s_h_a_d_e__internal__symmetry.html#a262d9e21cd6b81b8bda35ec22eb363dd',1,'ProSHADE_internal_symmetry::addAxisUnlessSame(proshade_unsign fold, proshade_double axX, proshade_double axY, proshade_double axZ, proshade_double axHeight, proshade_double averageFSC, std::vector&lt; proshade_double * &gt; *prosp, proshade_double axErr)'],['../namespace_pro_s_h_a_d_e__internal__symmetry.html#a00a784fd675e871b3b032d8f62013262',1,'ProSHADE_internal_symmetry::addAxisUnlessSame(proshade_unsign fold, proshade_double axX, proshade_double axY, proshade_double axZ, proshade_double axHeight, std::vector&lt; proshade_double * &gt; *prosp, proshade_double axErr)']]],
  ['addextraboundspace_2',['addExtraBoundSpace',['../namespace_pro_s_h_a_d_e__internal__map_manip.html#a7c88b1152378beca4ccee251f2fb5e06',1,'ProSHADE_internal_mapManip']]],
  ['addextraspace_3',['addExtraSpace',['../class_pro_s_h_a_d_e__settings.html#afb42ec0cd0f8abb54327c0e2c3025ed1',1,'ProSHADE_settings::addExtraSpace()'],['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7a402c710af1af5fabf7505848dad047',1,'ProSHADE_internal_data::ProSHADE_data::addExtraSpace()']]],
  ['addstructure_4',['addStructure',['../class_pro_s_h_a_d_e__settings.html#a0024967775d544e8512b6b157d53c1d1',1,'ProSHADE_settings']]],
  ['addtodblptrvector_5',['addToDblPtrVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#aa3103c7b5e2dc2cbf1778705c7693334',1,'ProSHADE_internal_misc']]],
  ['addtodoublevector_6',['addToDoubleVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a68c3eafaeea1c1873c33525f337f9d0b',1,'ProSHADE_internal_misc']]],
  ['addtodoublevectorvector_7',['addToDoubleVectorVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#ad9fbf28fda3873fc511fa2000ccba86c',1,'ProSHADE_internal_misc']]],
  ['addtosignedvector_8',['addToSignedVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a8a52d854a63ecad80c1805d601ffcf96',1,'ProSHADE_internal_misc']]],
  ['addtosigptrvector_9',['addToSigPtrVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a58f65a0980ed91146891e6c33ab7383a',1,'ProSHADE_internal_misc']]],
  ['addtosinglevector_10',['addToSingleVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a2d19df22d740c51de6edafbf679ae3fd',1,'ProSHADE_internal_misc']]],
  ['addtostringvector_11',['addToStringVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a60e14917f99e745c35cc400475ad6ca5',1,'ProSHADE_internal_misc']]],
  ['addtounsignvector_12',['addToUnsignVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a16336bdf0b391c953a549d3df115d691',1,'ProSHADE_internal_misc']]],
  ['addtounsignvectorvector_13',['addToUnsignVectorVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a86e2bb172f766ab4a620df482d2fe481',1,'ProSHADE_internal_misc']]],
  ['addtounsptrvector_14',['addToUnsPtrVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#ae36ae89607a7676c427956b88751f639',1,'ProSHADE_internal_misc']]],
  ['addzeropeaktogroups_15',['addZeroPeakToGroups',['../namespace_pro_s_h_a_d_e__internal__symmetry.html#ade9b717260e86c8f24bcbe6d17fe4e06',1,'ProSHADE_internal_symmetry']]],
  ['advanceglpolyvalue_16',['advanceGLPolyValue',['../namespace_pro_s_h_a_d_e__internal__maths.html#a4f2619c7f3b8d628af9cb356778e9807',1,'ProSHADE_internal_maths']]],
  ['alldetectedcaxes_17',['allDetectedCAxes',['../class_pro_s_h_a_d_e__settings.html#a2ac59de43dacdd96c7f89811f80d2e7e',1,'ProSHADE_settings']]],
  ['alldetecteddaxes_18',['allDetectedDAxes',['../class_pro_s_h_a_d_e__settings.html#a618c04a2c1d7f0a506d0bb3d7a0da444',1,'ProSHADE_settings']]],
  ['alldetectediaxes_19',['allDetectedIAxes',['../class_pro_s_h_a_d_e__settings.html#aa4957b0a47193ef1042028dc22b350f6',1,'ProSHADE_settings']]],
  ['alldetectedoaxes_20',['allDetectedOAxes',['../class_pro_s_h_a_d_e__settings.html#a4d869a528d0af64bc3688a9a48514061',1,'ProSHADE_settings']]],
  ['alldetectedtaxes_21',['allDetectedTAxes',['../class_pro_s_h_a_d_e__settings.html#ae42ba1e294d1887c71b763f9bb5519cc',1,'ProSHADE_settings']]],
  ['allocatecomputationmemory_22',['allocateComputationMemory',['../namespace_pro_s_h_a_d_e__internal__spherical_harmonics.html#aefc1302e14aeda70290390bda39da952',1,'ProSHADE_internal_sphericalHarmonics']]],
  ['allocateematrices_23',['allocateEMatrices',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4e78c033b2c8c038038887105d67b115',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocateinvsoftworkspaces_24',['allocateInvSOFTWorkspaces',['../namespace_pro_s_h_a_d_e__internal__distances.html#adf3050bb282928f5c1639dcdf2b3261f',1,'ProSHADE_internal_distances']]],
  ['allocatepeakoptimisationmemory_25',['allocatePeakOptimisationMemory',['../namespace_pro_s_h_a_d_e__internal__peak_search.html#aae6654470760e4848182efabbcfc0487',1,'ProSHADE_internal_peakSearch']]],
  ['allocateresolutionfouriermemory_26',['allocateResolutionFourierMemory',['../namespace_pro_s_h_a_d_e__internal__map_manip.html#af7557a0637b9c6fb9ccaf8fbf31cc928',1,'ProSHADE_internal_mapManip']]],
  ['allocaterotatedmap_27',['allocateRotatedMap',['../class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__sphere.html#a125477466283ee2e9b30d0299fc8e501',1,'ProSHADE_internal_spheres::ProSHADE_sphere']]],
  ['allocaterotatedshmemory_28',['allocateRotatedSHMemory',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa978d98f77a64fb16862b67a0de634be',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocaterrpmemory_29',['allocateRRPMemory',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4f8698493efda1aa3e057c266d5c697b',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocatesmoothingzscorememory_30',['allocateSmoothingZScoreMemory',['../namespace_pro_s_h_a_d_e__internal__peak_search.html#a26e06bc5d7848e1f9da5aeac60ceb989',1,'ProSHADE_internal_peakSearch']]],
  ['allocateso3coeffsspace_31',['allocateSO3CoeffsSpace',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abc4a61da919ae37b0a03d23df2461224',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocatetranslationfunctionmemory_32',['allocateTranslationFunctionMemory',['../namespace_pro_s_h_a_d_e__internal__overlay.html#a5f5eacf55d707e1d80d3df360fc0fe91',1,'ProSHADE_internal_overlay']]],
  ['allocatetrsigmaworkspace_33',['allocateTrSigmaWorkspace',['../namespace_pro_s_h_a_d_e__internal__distances.html#a365752e40ab7c1f09fb4b31827a43dba',1,'ProSHADE_internal_distances']]],
  ['allocatewignermatricesspace_34',['allocateWignerMatricesSpace',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aea644c87703e005507e187aa0ffa64b7',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocatewignerworkspace_35',['allocateWignerWorkspace',['../namespace_pro_s_h_a_d_e__internal__wigner.html#a2e3da1d3fe08d08bd94c55f9c73aeee3',1,'ProSHADE_internal_wigner']]],
  ['angulardistancewithborders_36',['angularDistanceWithBorders',['../class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere_peak_group.html#a8edbe0a36f9af831a2160455386863ba',1,'ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup']]],
  ['appliedmaskfilename_37',['appliedMaskFileName',['../class_pro_s_h_a_d_e__settings.html#a670cffe28bbdac027bffd8f5491d4266',1,'ProSHADE_settings']]],
  ['applycondonshortleyphase_38',['applyCondonShortleyPhase',['../namespace_pro_s_h_a_d_e__internal__spherical_harmonics.html#aa25c84ea82e4faeb0f41f738a56ca28d',1,'ProSHADE_internal_sphericalHarmonics']]],
  ['arraymedianandiqr_39',['arrayMedianAndIQR',['../namespace_pro_s_h_a_d_e__internal__maths.html#aa5a356017340781739a3bd66c716cfa5',1,'ProSHADE_internal_maths']]],
  ['autodeterminebandwidth_40',['autoDetermineBandwidth',['../namespace_pro_s_h_a_d_e__internal__spheres.html#a9592e9df40cf87ee1d1c43d6b3508e1c',1,'ProSHADE_internal_spheres']]],
  ['autodetermineintegrationorder_41',['autoDetermineIntegrationOrder',['../namespace_pro_s_h_a_d_e__internal__spheres.html#a612cf0a1e92ea1e5f0b9bdb820a4b60e',1,'ProSHADE_internal_spheres']]],
  ['autodeterminespheredistances_42',['autoDetermineSphereDistances',['../namespace_pro_s_h_a_d_e__internal__spheres.html#a51e14f3a4ce99f8e39497bbce12e28c7',1,'ProSHADE_internal_spheres']]],
  ['axestogrouptypesanitycheck_43',['axesToGroupTypeSanityCheck',['../_pro_s_h_a_d_e__data_8cpp.html#a188746757d4fe33cc7bca307aa367bc7',1,'ProSHADE_data.cpp']]],
  ['axiserrtolerance_44',['axisErrTolerance',['../class_pro_s_h_a_d_e__settings.html#a4627b03c4064d3de15efb3ebbf57ed78',1,'ProSHADE_settings']]]
];

==> proshade-0.7.6.1.tar.gz: proshade-0.7.6.1/proshade/documentation/html/search/all_0.js <==
var searchData=
[
  ['aangle_0',['aAngle',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa75beee618649d6fd9dc850a5a66a551',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['addaxisunlesssame_1',['addAxisUnlessSame',['../namespace_pro_s_h_a_d_e__internal__symmetry.html#a262d9e21cd6b81b8bda35ec22eb363dd',1,'ProSHADE_internal_symmetry::addAxisUnlessSame(proshade_unsign fold, proshade_double axX, proshade_double axY, proshade_double axZ, proshade_double axHeight, proshade_double averageFSC, std::vector&lt; proshade_double * &gt; *prosp, proshade_double axErr)'],['../namespace_pro_s_h_a_d_e__internal__symmetry.html#a00a784fd675e871b3b032d8f62013262',1,'ProSHADE_internal_symmetry::addAxisUnlessSame(proshade_unsign fold, proshade_double axX, proshade_double axY, proshade_double axZ, proshade_double axHeight, std::vector&lt; proshade_double * &gt; *prosp, proshade_double axErr)']]],
  ['addextraboundspace_2',['addExtraBoundSpace',['../namespace_pro_s_h_a_d_e__internal__map_manip.html#a7c88b1152378beca4ccee251f2fb5e06',1,'ProSHADE_internal_mapManip']]],
  ['addextraspace_3',['addExtraSpace',['../class_pro_s_h_a_d_e__settings.html#afb42ec0cd0f8abb54327c0e2c3025ed1',1,'ProSHADE_settings::addExtraSpace()'],['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a7a402c710af1af5fabf7505848dad047',1,'ProSHADE_internal_data::ProSHADE_data::addExtraSpace()']]],
  ['addstructure_4',['addStructure',['../class_pro_s_h_a_d_e__settings.html#a0024967775d544e8512b6b157d53c1d1',1,'ProSHADE_settings']]],
  ['addtodblptrvector_5',['addToDblPtrVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#aa3103c7b5e2dc2cbf1778705c7693334',1,'ProSHADE_internal_misc']]],
  ['addtodoublevector_6',['addToDoubleVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a68c3eafaeea1c1873c33525f337f9d0b',1,'ProSHADE_internal_misc']]],
  ['addtodoublevectorvector_7',['addToDoubleVectorVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#ad9fbf28fda3873fc511fa2000ccba86c',1,'ProSHADE_internal_misc']]],
  ['addtosignedvector_8',['addToSignedVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a8a52d854a63ecad80c1805d601ffcf96',1,'ProSHADE_internal_misc']]],
  ['addtosigptrvector_9',['addToSigPtrVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a58f65a0980ed91146891e6c33ab7383a',1,'ProSHADE_internal_misc']]],
  ['addtosinglevector_10',['addToSingleVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a2d19df22d740c51de6edafbf679ae3fd',1,'ProSHADE_internal_misc']]],
  ['addtostringvector_11',['addToStringVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a60e14917f99e745c35cc400475ad6ca5',1,'ProSHADE_internal_misc']]],
  ['addtounsignvector_12',['addToUnsignVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a16336bdf0b391c953a549d3df115d691',1,'ProSHADE_internal_misc']]],
  ['addtounsignvectorvector_13',['addToUnsignVectorVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#a86e2bb172f766ab4a620df482d2fe481',1,'ProSHADE_internal_misc']]],
  ['addtounsptrvector_14',['addToUnsPtrVector',['../namespace_pro_s_h_a_d_e__internal__misc.html#ae36ae89607a7676c427956b88751f639',1,'ProSHADE_internal_misc']]],
  ['addzeropeaktogroups_15',['addZeroPeakToGroups',['../namespace_pro_s_h_a_d_e__internal__symmetry.html#ade9b717260e86c8f24bcbe6d17fe4e06',1,'ProSHADE_internal_symmetry']]],
  ['advanceglpolyvalue_16',['advanceGLPolyValue',['../namespace_pro_s_h_a_d_e__internal__maths.html#a4f2619c7f3b8d628af9cb356778e9807',1,'ProSHADE_internal_maths']]],
  ['alldetectedcaxes_17',['allDetectedCAxes',['../class_pro_s_h_a_d_e__settings.html#a2ac59de43dacdd96c7f89811f80d2e7e',1,'ProSHADE_settings']]],
  ['alldetecteddaxes_18',['allDetectedDAxes',['../class_pro_s_h_a_d_e__settings.html#a618c04a2c1d7f0a506d0bb3d7a0da444',1,'ProSHADE_settings']]],
  ['alldetectediaxes_19',['allDetectedIAxes',['../class_pro_s_h_a_d_e__settings.html#aa4957b0a47193ef1042028dc22b350f6',1,'ProSHADE_settings']]],
  ['alldetectedoaxes_20',['allDetectedOAxes',['../class_pro_s_h_a_d_e__settings.html#a4d869a528d0af64bc3688a9a48514061',1,'ProSHADE_settings']]],
  ['alldetectedtaxes_21',['allDetectedTAxes',['../class_pro_s_h_a_d_e__settings.html#ae42ba1e294d1887c71b763f9bb5519cc',1,'ProSHADE_settings']]],
  ['allocatecomputationmemory_22',['allocateComputationMemory',['../namespace_pro_s_h_a_d_e__internal__spherical_harmonics.html#aefc1302e14aeda70290390bda39da952',1,'ProSHADE_internal_sphericalHarmonics']]],
  ['allocateematrices_23',['allocateEMatrices',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4e78c033b2c8c038038887105d67b115',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocateinvsoftworkspaces_24',['allocateInvSOFTWorkspaces',['../namespace_pro_s_h_a_d_e__internal__distances.html#adf3050bb282928f5c1639dcdf2b3261f',1,'ProSHADE_internal_distances']]],
  ['allocatepeakoptimisationmemory_25',['allocatePeakOptimisationMemory',['../namespace_pro_s_h_a_d_e__internal__peak_search.html#aae6654470760e4848182efabbcfc0487',1,'ProSHADE_internal_peakSearch']]],
  ['allocateresolutionfouriermemory_26',['allocateResolutionFourierMemory',['../namespace_pro_s_h_a_d_e__internal__map_manip.html#af7557a0637b9c6fb9ccaf8fbf31cc928',1,'ProSHADE_internal_mapManip']]],
  ['allocaterotatedmap_27',['allocateRotatedMap',['../class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__sphere.html#a125477466283ee2e9b30d0299fc8e501',1,'ProSHADE_internal_spheres::ProSHADE_sphere']]],
  ['allocaterotatedshmemory_28',['allocateRotatedSHMemory',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa978d98f77a64fb16862b67a0de634be',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocaterrpmemory_29',['allocateRRPMemory',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4f8698493efda1aa3e057c266d5c697b',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocatesmoothingzscorememory_30',['allocateSmoothingZScoreMemory',['../namespace_pro_s_h_a_d_e__internal__peak_search.html#a26e06bc5d7848e1f9da5aeac60ceb989',1,'ProSHADE_internal_peakSearch']]],
  ['allocateso3coeffsspace_31',['allocateSO3CoeffsSpace',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abc4a61da919ae37b0a03d23df2461224',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocatetranslationfunctionmemory_32',['allocateTranslationFunctionMemory',['../namespace_pro_s_h_a_d_e__internal__overlay.html#a5f5eacf55d707e1d80d3df360fc0fe91',1,'ProSHADE_internal_overlay']]],
  ['allocatetrsigmaworkspace_33',['allocateTrSigmaWorkspace',['../namespace_pro_s_h_a_d_e__internal__distances.html#a365752e40ab7c1f09fb4b31827a43dba',1,'ProSHADE_internal_distances']]],
  ['allocatewignermatricesspace_34',['allocateWignerMatricesSpace',['../class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aea644c87703e005507e187aa0ffa64b7',1,'ProSHADE_internal_data::ProSHADE_data']]],
  ['allocatewignerworkspace_35',['allocateWignerWorkspace',['../namespace_pro_s_h_a_d_e__internal__wigner.html#a2e3da1d3fe08d08bd94c55f9c73aeee3',1,'ProSHADE_internal_wigner']]],
  ['angulardistancewithborders_36',['angularDistanceWithBorders',['../class_pro_s_h_a_d_e__internal__spheres_1_1_pro_s_h_a_d_e__rot_fun__sphere_peak_group.html#a8edbe0a36f9af831a2160455386863ba',1,'ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup']]],
  ['appliedmaskfilename_37',['appliedMaskFileName',['../class_pro_s_h_a_d_e__settings.html#a670cffe28bbdac027bffd8f5491d4266',1,'ProSHADE_settings']]],
  ['applycondonshortleyphase_38',['applyCondonShortleyPhase',['../namespace_pro_s_h_a_d_e__internal__spherical_harmonics.html#aa25c84ea82e4faeb0f41f738a56ca28d',1,'ProSHADE_internal_sphericalHarmonics']]],
  ['applymask_39',['applyMask',['../namespace_pro_s_h_a_d_e__internal__io.html#aa5e21f1b3dc18338da35951b248e6e38',1,'ProSHADE_internal_io']]],
  ['applymaskfromarray_40',['applyMaskFromArray',['../namespace_pro_s_h_a_d_e__internal__io.html#a354a3899d17c6c5d4bad042dc00f4554',1,'ProSHADE_internal_io']]],
  ['applyweights_41',['applyWeights',['../namespace_pro_s_h_a_d_e__internal__io.html#a2047cb9106e44b8de3174e34b9578f80',1,'ProSHADE_internal_io']]],
  ['applyweightsfromarray_42',['applyWeightsFromArray',['../namespace_pro_s_h_a_d_e__internal__io.html#adae94658a4eec4c994e10d267b00fe4c',1,'ProSHADE_internal_io']]],
  ['arraymedianandiqr_43',['arrayMedianAndIQR',['../namespace_pro_s_h_a_d_e__internal__maths.html#aa5a356017340781739a3bd66c716cfa5',1,'ProSHADE_internal_maths']]],
  ['autodeterminebandwidth_44',['autoDetermineBandwidth',['../namespace_pro_s_h_a_d_e__internal__spheres.html#a9592e9df40cf87ee1d1c43d6b3508e1c',1,'ProSHADE_internal_spheres']]],
  ['autodetermineintegrationorder_45',['autoDetermineIntegrationOrder',['../namespace_pro_s_h_a_d_e__internal__spheres.html#a612cf0a1e92ea1e5f0b9bdb820a4b60e',1,'ProSHADE_internal_spheres']]],
  ['autodeterminespheredistances_46',['autoDetermineSphereDistances',['../namespace_pro_s_h_a_d_e__internal__spheres.html#a51e14f3a4ce99f8e39497bbce12e28c7',1,'ProSHADE_internal_spheres']]],
  ['axestogrouptypesanitycheck_47',['axesToGroupTypeSanityCheck',['../_pro_s_h_a_d_e__data_8cpp.html#a188746757d4fe33cc7bca307aa367bc7',1,'ProSHADE_data.cpp']]],
  ['axiserrtolerance_48',['axisErrTolerance',['../class_pro_s_h_a_d_e__settings.html#a4627b03c4064d3de15efb3ebbf57ed78',1,'ProSHADE_settings']]]
];
